@@ -1,6 +1,7 @@
 import numpy as np
 from numba import cuda
 from numba import jit
+import math
 from .fs import FocalSet
     
 class Lattice:
@@ -53,11 +54,13 @@ class Lattice:
                 return self.b
             else:
                 # Initialize the array to store the belief of each subset
-                self.b = np.zeros(2^self.fod.n)
+                print(self.fod.n)
+                self.b = np.zeros(2**self.fod.n)
+                print(self.b.size)
                 
                 # Define the dimensions of the parallelization
                 threadsperblock = 128 # TODO which one is the best to use?
-                blockspergrid = self.b.size / threadsperblock
+                blockspergrid = math.ceil(self.b.size / threadsperblock)
                 
                 # Get the focal set as two diffent arrays
                 elements, bpas = self.fs.as_arrays()
@@ -69,7 +72,7 @@ class Lattice:
                 
                 self.__bel[blockspergrid, threadsperblock](d_elements, d_bpa, d_b)
                 
-                # Get the results back
+                # # Get the results back
                 d_b.copy_to_host(self.b)
                 # TODO should I clean somehow the GPU?
                 
